@@ -474,7 +474,7 @@ put_declaration()
 		if (nkey > 0) {
 			i = 0;
 			for (;;) {
-				fprintf(out, "\t\tK%s", keyword[i].k_key);
+				fprintf(out, "\t\tsK%s", keyword[i].k_key);
 				if (++i == nkey) {
 					fprintf(out, ");\n");
 					break;
