@@ -30,7 +30,7 @@ static object LI1(va_alist)
 	base[4]= (V4);
 	base[5]= (V5);
 	vs_top=(vs_base=base+0)+6;
-	(void) (*Lnk42)();
+	siLmake_structure();
 	vs_top=sup;
 	{object V6 = vs_base[0];
 	VMR1(V6)}}
@@ -63,7 +63,7 @@ TTL:;
 	V17= Cnil;
 	if(!(endp((V8)))){
 	goto T16;}
-	(void)((*(LnkLI43))(VV[1],small_fixnum(1),small_fixnum(0)));
+	(void)((*(LnkLI42))(VV[1],small_fixnum(1),small_fixnum(0)));
 T16:;
 	bds_bind(VV[2],symbol_value(VV[2]));
 	{register object V18;
@@ -82,10 +82,10 @@ T25:;
 	if(!(endp(cdr((V19))))){
 	goto T29;}
 T30:;
-	(void)((VFUN_NARGS=2,(*(LnkLI44))(VV[3],(V19))));
+	(void)((VFUN_NARGS=2,(*(LnkLI43))(VV[3],(V19))));
 T29:;
 	{object V20;
-	V20= (VFUN_NARGS=6,(*(LnkLI45))(VV[4],car((V19)),VV[5],Cnil,VV[6],Cnil));
+	V20= (VFUN_NARGS=6,(*(LnkLI44))(VV[4],car((V19)),VV[5],Cnil,VV[6],Cnil));
 	(VV[2]->s.s_dbind)= make_cons((V20),(VV[2]->s.s_dbind));
 	V21= list(2,(V20),cdr((V19)));
 	V15= make_cons(/* INLINE-ARGS */V21,(V15));}
@@ -96,7 +96,7 @@ T20:;
 	base[1]= cdr((V8));
 	base[2]= Ct;
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	if(vs_base<vs_top){
 	V9= vs_base[0];
 	vs_base++;
@@ -123,13 +123,13 @@ T20:;
 	V13= Cnil;}
 	vs_top=sup;
 	bds_bind(VV[7],symbol_value(VV[7]));
-	(void)((*(LnkLI47))((V10)));
-	(void)((*(LnkLI48))(Cnil,(V11),(V12)));
-	V9= (*(LnkLI49))((V13),(V9));
+	(void)((*(LnkLI46))((V10)));
+	(void)((*(LnkLI47))(Cnil,(V11),(V12)));
+	V9= (*(LnkLI48))((V13),(V9));
 	bds_unwind1;
 	base[1]= cadr((V9));
 	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk50)();
+	(void) (*Lnk49)();
 	vs_top=sup;
 	V14= vs_base[0];
 	bds_unwind1;
@@ -155,8 +155,8 @@ T61:;
 	{object V24;
 	V25= cadr((V23));
 	V26= structure_ref(car((V23)),VV[0],0);
-	V24= (VFUN_NARGS=2,(*(LnkLI51))(/* INLINE-ARGS */V25,/* INLINE-ARGS */V26));
-	(void)((*(LnkLI52))((V14),cadr((V24))));
+	V24= (VFUN_NARGS=2,(*(LnkLI50))(/* INLINE-ARGS */V25,/* INLINE-ARGS */V26));
+	(void)((*(LnkLI51))((V14),cadr((V24))));
 	V27= list(2,car((V23)),(V24));
 	V17= make_cons(/* INLINE-ARGS */V27,(V17));
 	bds_unwind1;
@@ -175,8 +175,8 @@ T65:;
 	{object V28;
 	V29= cadr((V23));
 	V30= structure_ref(car((V23)),VV[0],0);
-	V28= (VFUN_NARGS=2,(*(LnkLI51))(/* INLINE-ARGS */V29,/* INLINE-ARGS */V30));
-	(void)((*(LnkLI52))((V14),cadr((V28))));
+	V28= (VFUN_NARGS=2,(*(LnkLI50))(/* INLINE-ARGS */V29,/* INLINE-ARGS */V30));
+	(void)((*(LnkLI51))((V14),cadr((V28))));
 	V31= list(2,car((V23)),(V28));
 	V16= make_cons(/* INLINE-ARGS */V31,(V16));
 	bds_unwind1;
@@ -267,29 +267,29 @@ T128:;{object V47;
 	setq(VV[19],make_cons(car((V45)),symbol_value(VV[19])));
 	{register object V49;
 	V49= car((V45));
-	V50= (*(LnkLI53))();
+	V50= (*(LnkLI52))();
 	(void)(structure_set((V49),VV[0],1,/* INLINE-ARGS */V50));
 	princ_str("\n	",VV[20]);
 	V51= structure_ref((V49),VV[0],1);
-	(void)((*(LnkLI54))(/* INLINE-ARGS */V51));
+	(void)((*(LnkLI53))(/* INLINE-ARGS */V51));
 	princ_str("=make_cclosure_new(LC",VV[20]);
 	V52= structure_ref((V49),VV[0],3);
-	(void)((*(LnkLI55))(/* INLINE-ARGS */V52));
+	(void)((*(LnkLI54))(/* INLINE-ARGS */V52));
 	princ_str(",Cnil,",VV[20]);
-	(void)((VFUN_NARGS=0,(*(LnkLI56))()));
+	(void)((VFUN_NARGS=0,(*(LnkLI55))()));
 	princ_str(",Cdata);",VV[20]);
 	princ_str("\n	",VV[20]);
 	V53= structure_ref((V49),VV[0],1);
-	(void)((*(LnkLI54))(/* INLINE-ARGS */V53));
+	(void)((*(LnkLI53))(/* INLINE-ARGS */V53));
 	princ_str("=MMcons(",VV[20]);
 	V54= structure_ref((V49),VV[0],1);
-	(void)((*(LnkLI54))(/* INLINE-ARGS */V54));
+	(void)((*(LnkLI53))(/* INLINE-ARGS */V54));
 	princ_char(44,VV[20]);
-	(void)((VFUN_NARGS=0,(*(LnkLI56))()));
+	(void)((VFUN_NARGS=0,(*(LnkLI55))()));
 	princ_str(");",VV[20]);
 	V55= structure_ref((V49),VV[0],1);
-	(void)((*(LnkLI57))(/* INLINE-ARGS */V55));
-	V56= (*(LnkLI58))();
+	(void)((*(LnkLI56))(/* INLINE-ARGS */V55));
+	V56= (*(LnkLI57))();
 	(void)(structure_set((V49),VV[0],2,/* INLINE-ARGS */V56));}
 	V44= cdr((V44));
 	V45= car((V44));
@@ -297,7 +297,7 @@ T128:;{object V47;
 T117:;
 	base[6]= (V38);
 	vs_top=(vs_base=base+6)+1;
-	(void) (*Lnk59)();
+	(void) (*Lnk58)();
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
@@ -337,7 +337,7 @@ TTL:;
 	bds_bind(VV[2],symbol_value(VV[2]));
 	if(!(endp((V58)))){
 	goto T174;}
-	(void)((*(LnkLI43))(VV[21],small_fixnum(1),small_fixnum(0)));
+	(void)((*(LnkLI42))(VV[21],small_fixnum(1),small_fixnum(0)));
 T174:;
 	{object V70;
 	register object V71;
@@ -355,7 +355,7 @@ T182:;
 	if(!(endp(cdr((V71))))){
 	goto T186;}
 T187:;
-	(void)((VFUN_NARGS=2,(*(LnkLI44))(VV[22],(V71))));
+	(void)((VFUN_NARGS=2,(*(LnkLI43))(VV[22],(V71))));
 T186:;
 	{register object x= car((V71)),V72= (V68);
 	while(!endp(V72))
@@ -364,11 +364,11 @@ T186:;
 	}else V72=V72->c.c_cdr;
 	goto T193;}
 T195:;
-	(void)((VFUN_NARGS=2,(*(LnkLI44))(VV[23],car((V71)))));
+	(void)((VFUN_NARGS=2,(*(LnkLI43))(VV[23],car((V71)))));
 T193:;
 	V68= make_cons(car((V71)),(V68));
 	{object V73;
-	V73= (VFUN_NARGS=6,(*(LnkLI45))(VV[4],car((V71)),VV[5],Cnil,VV[6],Cnil));
+	V73= (VFUN_NARGS=6,(*(LnkLI44))(VV[4],car((V71)),VV[5],Cnil,VV[6],Cnil));
 	(VV[2]->s.s_dbind)= make_cons((V73),(VV[2]->s.s_dbind));
 	V74= list(4,(V73),Cnil,Cnil,cdr((V71)));
 	V65= make_cons(/* INLINE-ARGS */V74,(V65));}
@@ -380,7 +380,7 @@ T177:;
 	base[1]= cdr((V58));
 	base[2]= Ct;
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	if(vs_base<vs_top){
 	V59= vs_base[0];
 	vs_base++;
@@ -407,13 +407,13 @@ T177:;
 	V63= Cnil;}
 	vs_top=sup;
 	bds_bind(VV[7],symbol_value(VV[7]));
-	(void)((*(LnkLI47))((V60)));
-	(void)((*(LnkLI48))(Cnil,(V61),(V62)));
-	V59= (*(LnkLI49))((V63),(V59));
+	(void)((*(LnkLI46))((V60)));
+	(void)((*(LnkLI47))(Cnil,(V61),(V62)));
+	V59= (*(LnkLI48))((V63),(V59));
 	bds_unwind1;
 	base[1]= cadr((V59));
 	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk50)();
+	(void) (*Lnk49)();
 	vs_top=sup;
 	V64= vs_base[0];
 T223:;
@@ -444,8 +444,8 @@ T232:;
 	{object V79;
 	V80= cadddr((V76));
 	V81= structure_ref(car((V76)),VV[0],0);
-	V79= (VFUN_NARGS=2,(*(LnkLI51))(/* INLINE-ARGS */V80,/* INLINE-ARGS */V81));
-	(void)((*(LnkLI52))((V64),cadr((V79))));
+	V79= (VFUN_NARGS=2,(*(LnkLI50))(/* INLINE-ARGS */V80,/* INLINE-ARGS */V81));
+	(void)((*(LnkLI51))((V64),cadr((V79))));
 	V82= list(2,car((V76)),(V79));
 	V66= make_cons(/* INLINE-ARGS */V82,(V66));
 	bds_unwind1;
@@ -492,8 +492,8 @@ T270:;
 	{object V87;
 	V88= cadddr((V84));
 	V89= structure_ref(car((V84)),VV[0],0);
-	V87= (VFUN_NARGS=2,(*(LnkLI51))(/* INLINE-ARGS */V88,/* INLINE-ARGS */V89));
-	(void)((*(LnkLI52))((V64),cadr((V87))));
+	V87= (VFUN_NARGS=2,(*(LnkLI50))(/* INLINE-ARGS */V88,/* INLINE-ARGS */V89));
+	(void)((*(LnkLI51))((V64),cadr((V87))));
 	V90= list(2,car((V84)),(V87));
 	V67= make_cons(/* INLINE-ARGS */V90,(V67));
 	bds_unwind1;
@@ -576,17 +576,17 @@ T327:;
 T328:;
 	{register object V102;
 	V102= car((V101));
-	V103= (*(LnkLI53))();
+	V103= (*(LnkLI52))();
 	(void)(structure_set((V102),VV[0],1,/* INLINE-ARGS */V103));
 	princ_str("\n	",VV[20]);
 	V104= structure_ref((V102),VV[0],1);
-	(void)((*(LnkLI54))(/* INLINE-ARGS */V104));
+	(void)((*(LnkLI53))(/* INLINE-ARGS */V104));
 	princ_str("=MMcons(Cnil,",VV[20]);
-	(void)((VFUN_NARGS=0,(*(LnkLI56))()));
+	(void)((VFUN_NARGS=0,(*(LnkLI55))()));
 	princ_str(");",VV[20]);
 	V105= structure_ref((V102),VV[0],1);
-	(void)((*(LnkLI57))(/* INLINE-ARGS */V105));
-	V106= (*(LnkLI58))();
+	(void)((*(LnkLI56))(/* INLINE-ARGS */V105));
+	V106= (*(LnkLI57))();
 	(void)(structure_set((V102),VV[0],2,/* INLINE-ARGS */V106));}
 	V100= cdr((V100));
 	V101= car((V100));
@@ -632,12 +632,12 @@ T376:;{object V115;
 	setq(VV[19],make_cons(car((V113)),symbol_value(VV[19])));
 	princ_str("\n	",VV[20]);
 	V117= structure_ref(car((V113)),VV[0],1);
-	(void)((*(LnkLI60))(/* INLINE-ARGS */V117));
+	(void)((*(LnkLI59))(/* INLINE-ARGS */V117));
 	princ_str("=make_cclosure_new(LC",VV[20]);
 	V118= structure_ref(car((V113)),VV[0],3);
-	(void)((*(LnkLI55))(/* INLINE-ARGS */V118));
+	(void)((*(LnkLI54))(/* INLINE-ARGS */V118));
 	princ_str(",Cnil,",VV[20]);
-	(void)((VFUN_NARGS=0,(*(LnkLI56))()));
+	(void)((VFUN_NARGS=0,(*(LnkLI55))()));
 	princ_str(",Cdata);",VV[20]);
 	V112= cdr((V112));
 	V113= car((V112));
@@ -645,7 +645,7 @@ T376:;{object V115;
 T365:;
 	base[5]= (V99);
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk59)();
+	(void) (*Lnk58)();
 	bds_unwind1;
 	bds_unwind1;
 	return;
@@ -673,7 +673,7 @@ TTL:;
 	bds_bind(VV[7],symbol_value(VV[7]));
 	if(!(endp((V120)))){
 	goto T402;}
-	(void)((*(LnkLI43))(VV[24],small_fixnum(1),small_fixnum(0)));
+	(void)((*(LnkLI42))(VV[24],small_fixnum(1),small_fixnum(0)));
 T402:;
 	{register object V126;
 	register object V127;
@@ -691,10 +691,10 @@ T410:;
 	if(!(endp(cdr((V127))))){
 	goto T414;}
 T415:;
-	(void)((VFUN_NARGS=2,(*(LnkLI44))(VV[25],(V127))));
+	(void)((VFUN_NARGS=2,(*(LnkLI43))(VV[25],(V127))));
 T414:;
 	V128= car((V127));
-	V129= (*(LnkLI61))(car((V127)),cadr((V127)),cddr((V127)));
+	V129= (*(LnkLI60))(car((V127)),cadr((V127)),cddr((V127)));
 	V130= list(2,/* INLINE-ARGS */V128,caddr(/* INLINE-ARGS */V129));
 	(VV[2]->s.s_dbind)= make_cons(/* INLINE-ARGS */V130,(VV[2]->s.s_dbind));
 	V126= cdr((V126));
@@ -704,7 +704,7 @@ T405:;
 	base[2]= cdr((V120));
 	base[3]= Ct;
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk46)();
+	(void) (*Lnk45)();
 	if(vs_base<vs_top){
 	V121= vs_base[0];
 	vs_base++;
@@ -730,9 +730,9 @@ T405:;
 	}else{
 	V125= Cnil;}
 	vs_top=sup;
-	(void)((*(LnkLI47))((V122)));
-	(void)((*(LnkLI48))(Cnil,(V123),(V124)));
-	{object V131 = (*(LnkLI49))((V125),(V121));
+	(void)((*(LnkLI46))((V122)));
+	(void)((*(LnkLI47))(Cnil,(V123),(V124)));
+	{object V131 = (*(LnkLI48))((V125),(V121));
 	bds_unwind1;
 	bds_unwind1;
 	VMR6(V131)}}
@@ -869,10 +869,10 @@ TTL:;
 	bds_bind(VV[13],symbol_value(VV[13]));
 	if((cadr((V159)))==Cnil){
 	goto T513;}
-	(void)((*(LnkLI62))((V160)));
+	(void)((*(LnkLI61))((V160)));
 	princ_str("\n	cclosure_call(",VV[20]);
 	V161= structure_ref(car((V159)),VV[0],2);
-	(void)((*(LnkLI63))(/* INLINE-ARGS */V161));
+	(void)((*(LnkLI62))(/* INLINE-ARGS */V161));
 	princ_str(");",VV[20]);
 	goto T511;
 T513:;
@@ -886,7 +886,7 @@ T513:;
 	goto T521;}
 	if(!((symbol_value(VV[30]))==(VV[31]))){
 	goto T521;}
-	if(((*(LnkLI64))())==Cnil){
+	if(((*(LnkLI63))())==Cnil){
 	goto T521;}
 	if(!((length((V160)))==(length(cdr(symbol_value(VV[29])))))){
 	goto T521;}
@@ -908,29 +908,29 @@ T541:;
 	V163=MMcdr(V163)=MMcons(Cnil,Cnil);
 	goto T541;}
 T540:;
-	(void)((*(LnkLI65))(V162,(V160)));
+	(void)((*(LnkLI64))(V162,(V160)));
 	if((cdr((VV[30]->s.s_dbind)))==Cnil){
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
 	goto T535;}
 	princ_str("\nT",VV[20]);
-	(void)((*(LnkLI55))(car((VV[30]->s.s_dbind))));
+	(void)((*(LnkLI54))(car((VV[30]->s.s_dbind))));
 	princ_str(":;",VV[20]);
 	bds_unwind1;
 	bds_unwind1;
 	bds_unwind1;
 T535:;
-	(void)((*(LnkLI66))(VV[36]));
+	(void)((*(LnkLI65))(VV[36]));
 	princ_str("\n	goto TTL;",VV[20]);
 	V166= structure_ref(car((V159)),VV[0],0);
-	(void)((VFUN_NARGS=2,(*(LnkLI67))(VV[37],/* INLINE-ARGS */V166)));
+	(void)((VFUN_NARGS=2,(*(LnkLI66))(VV[37],/* INLINE-ARGS */V166)));
 	goto T511;
 T521:;
-	(void)((*(LnkLI62))((V160)));
+	(void)((*(LnkLI61))((V160)));
 	princ_str("\n	L",VV[20]);
 	V167= structure_ref(car((V159)),VV[0],3);
-	(void)((*(LnkLI55))(/* INLINE-ARGS */V167));
+	(void)((*(LnkLI54))(/* INLINE-ARGS */V167));
 	princ_char(40,VV[20]);
 	{register int V168;
 	register int V169;
@@ -943,7 +943,7 @@ T560:;
 T561:;
 	princ_str("base",VV[20]);
 	V170 = make_fixnum(V169);
-	(void)((*(LnkLI55))(V170));
+	(void)((*(LnkLI54))(V170));
 	princ_char(44,VV[20]);
 	V169= (V169)+1;
 	goto T560;}
@@ -953,39 +953,38 @@ T556:;
 	if(number_compare(/* INLINE-ARGS */V171,symbol_value(VV[16]))==0){
 	goto T574;}
 	V172= structure_ref(car((V159)),VV[0],4);
-	(void)((*(LnkLI55))(/* INLINE-ARGS */V172));
+	(void)((*(LnkLI54))(/* INLINE-ARGS */V172));
 T574:;
 	princ_str(");",VV[20]);
 	setq(VV[38],Ct);
 T511:;
-	{object V173 = (VFUN_NARGS=1,(*(LnkLI68))(VV[39]));
+	{object V173 = (VFUN_NARGS=1,(*(LnkLI67))(VV[39]));
 	bds_unwind1;
 	VMR10(V173)}
 }
-static object  LnkTLI68(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[68],&LnkLI68,ap);} /* UNWIND-EXIT */
-static object  LnkTLI67(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[67],&LnkLI67,ap);} /* CMPNOTE */
-static object  LnkTLI66(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[66],&LnkLI66,1,ap);} /* UNWIND-NO-EXIT */
-static object  LnkTLI65(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[65],&LnkLI65,2,ap);} /* C2PSETQ */
-static object  LnkTLI64(){return call_proc0(VV[64],&LnkLI64);} /* TAIL-RECURSION-POSSIBLE */
-static object  LnkTLI63(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[63],&LnkLI63,1,ap);} /* WT-CCB-VS */
-static object  LnkTLI62(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[62],&LnkLI62,1,ap);} /* PUSH-ARGS */
-static object  LnkTLI61(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[61],&LnkLI61,3,ap);} /* DEFMACRO* */
-static object  LnkTLI60(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[60],&LnkLI60,1,ap);} /* WT-VS* */
-static LnkT59(){ call_or_link(VV[59],&Lnk59);} /* C2EXPR */
-static object  LnkTLI58(){return call_proc0(VV[58],&LnkLI58);} /* CCB-VS-PUSH */
-static object  LnkTLI57(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[57],&LnkLI57,1,ap);} /* CLINK */
-static object  LnkTLI56(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[56],&LnkLI56,ap);} /* WT-CLINK */
-static object  LnkTLI55(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[55],&LnkLI55,1,ap);} /* WT1 */
-static object  LnkTLI54(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[54],&LnkLI54,1,ap);} /* WT-VS */
-static object  LnkTLI53(){return call_proc0(VV[53],&LnkLI53);} /* VS-PUSH */
-static object  LnkTLI52(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[52],&LnkLI52,2,ap);} /* ADD-INFO */
-static object  LnkTLI51(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[51],&LnkLI51,ap);} /* C1LAMBDA-EXPR */
-static LnkT50(){ call_or_link(VV[50],&Lnk50);} /* COPY-INFO */
-static object  LnkTLI49(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[49],&LnkLI49,2,ap);} /* C1DECL-BODY */
-static object  LnkTLI48(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[48],&LnkLI48,3,ap);} /* CHECK-VDECL */
-static object  LnkTLI47(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[47],&LnkLI47,1,ap);} /* C1ADD-GLOBALS */
-static LnkT46(){ call_or_link(VV[46],&Lnk46);} /* C1BODY */
-static object  LnkTLI45(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[45],&LnkLI45,ap);} /* MAKE-FUN */
-static object  LnkTLI44(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[44],&LnkLI44,ap);} /* CMPERR */
-static object  LnkTLI43(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[43],&LnkLI43,3,ap);} /* TOO-FEW-ARGS */
-static LnkT42(){ call_or_link(VV[42],&Lnk42);} /* MAKE-STRUCTURE */
+static object  LnkTLI67(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[67],&LnkLI67,ap);} /* UNWIND-EXIT */
+static object  LnkTLI66(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[66],&LnkLI66,ap);} /* CMPNOTE */
+static object  LnkTLI65(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[65],&LnkLI65,1,ap);} /* UNWIND-NO-EXIT */
+static object  LnkTLI64(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[64],&LnkLI64,2,ap);} /* C2PSETQ */
+static object  LnkTLI63(){return call_proc0(VV[63],&LnkLI63);} /* TAIL-RECURSION-POSSIBLE */
+static object  LnkTLI62(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[62],&LnkLI62,1,ap);} /* WT-CCB-VS */
+static object  LnkTLI61(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[61],&LnkLI61,1,ap);} /* PUSH-ARGS */
+static object  LnkTLI60(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[60],&LnkLI60,3,ap);} /* DEFMACRO* */
+static object  LnkTLI59(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[59],&LnkLI59,1,ap);} /* WT-VS* */
+static LnkT58(){ call_or_link(VV[58],&Lnk58);} /* C2EXPR */
+static object  LnkTLI57(){return call_proc0(VV[57],&LnkLI57);} /* CCB-VS-PUSH */
+static object  LnkTLI56(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[56],&LnkLI56,1,ap);} /* CLINK */
+static object  LnkTLI55(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[55],&LnkLI55,ap);} /* WT-CLINK */
+static object  LnkTLI54(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[54],&LnkLI54,1,ap);} /* WT1 */
+static object  LnkTLI53(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[53],&LnkLI53,1,ap);} /* WT-VS */
+static object  LnkTLI52(){return call_proc0(VV[52],&LnkLI52);} /* VS-PUSH */
+static object  LnkTLI51(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[51],&LnkLI51,2,ap);} /* ADD-INFO */
+static object  LnkTLI50(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[50],&LnkLI50,ap);} /* C1LAMBDA-EXPR */
+static LnkT49(){ call_or_link(VV[49],&Lnk49);} /* COPY-INFO */
+static object  LnkTLI48(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[48],&LnkLI48,2,ap);} /* C1DECL-BODY */
+static object  LnkTLI47(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[47],&LnkLI47,3,ap);} /* CHECK-VDECL */
+static object  LnkTLI46(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[46],&LnkLI46,1,ap);} /* C1ADD-GLOBALS */
+static LnkT45(){ call_or_link(VV[45],&Lnk45);} /* C1BODY */
+static object  LnkTLI44(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[44],&LnkLI44,ap);} /* MAKE-FUN */
+static object  LnkTLI43(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[43],&LnkLI43,ap);} /* CMPERR */
+static object  LnkTLI42(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[42],&LnkLI42,3,ap);} /* TOO-FEW-ARGS */
