@@ -4,18 +4,6 @@
 ((((FIXtemp=(x))+SMALL_FIXNUM_LIMIT)&(-2*SMALL_FIXNUM_LIMIT))==0?small_fixnum(FIXtemp):make_fixnum(FIXtemp))
 
 
-
-#ifdef DEBUG_AVMA
-#define save_avma long lvma = (in_saved_avma = 1, avma)
-#define restore_avma avma = (in_saved_avma = 0, lvma)
-#else
-#define save_avma long lvma = avma
-#define restore_avma avma = lvma
-#endif
-EXTER unsigned long avma;
-EXTER GEN gzero;
-EXTER GEN icopy_x;
-
 object make_integer();
   /* copy x to y, increasing space by factor of 2  */
 
