@@ -34,7 +34,6 @@ char stdin_buf[], stdout_buf[];
 
 EXTER object user_package;
 
-#define MAXPATHLEN 512
 #define TRUE 1
 #define FALSE 0
 
@@ -123,17 +122,17 @@ EXTER bool PRINTpackage;
 EXTER bool PRINTstructure;
 
 /* from format.c */
-EXTER object fmt_stream;
-EXTER int ctl_origin;
-EXTER int ctl_index;
-EXTER int ctl_end;
-EXTER object *fmt_base;
-EXTER int fmt_index;
-EXTER int fmt_end;
+EXTER VOL object fmt_stream;
+EXTER VOL int ctl_origin;
+EXTER VOL int ctl_index;
+EXTER VOL int ctl_end;
+EXTER  object * VOL fmt_base;
+EXTER VOL int fmt_index;
+EXTER VOL int fmt_end;
 typedef jmp_buf *jmp_bufp;
-EXTER jmp_buf *fmt_jmp_buf;
-EXTER int fmt_indents;
-EXTER object fmt_string;
+EXTER jmp_bufp VOL fmt_jmp_bufp;
+EXTER VOL int fmt_indents;
+EXTER VOL object fmt_string;
 EXTER object endp_temp;
 
 /* eval */
@@ -188,3 +187,7 @@ EXTER struct printStruct *printStructBufp;
 EXTER object sSY;
 
 #define	inheap(pp)	((char *)(pp) < heap_end)
+
+char *lisp_copy_to_null_terminated();
+
+
