@@ -1,10 +1,21 @@
 #define SUN4
   
 #include "bsd.h"
+#ifdef i386
+/* #define DBEGIN 0x8000000 */
+#define LITTLE_END 
+#define NULL_OR_ON_C_STACK(x) (((x)==0) || ((unsigned long) x) < 0x8048000)
+#define IS_X86
+#else
 #include "sparc.h"
+#endif
 
 
 #ifdef __svr4__
+
+/* dont conflict with libnls */
+#define shifts gcl_shifts
+
 #define UNIXSAVE "unexelf.c"
 #ifdef IN_UNIXSAVE
 #define round_up round_up1
@@ -20,7 +31,7 @@
 #endif
 
 #define GET_FAULT_ADDR(sig,code,scp,addr) \
-  (code ? ((siginfo_t *)code )->si_addr : error("no address info"))
+  (code ? ((siginfo_t *)code )->si_addr : (error("no address info"),0))
 
 #define SETUP_SIG_STACK \
 { static stack_t estack ; \
@@ -33,7 +44,7 @@
 #undef HAVE_AOUT
 #define HAVE_AOUT <elf.h>
 #define HAVE_ELF
-
+/*  for 2.5 need different one 
 #define SEEK_TO_END_OFILE(fp)\
   do {      Elf32_Ehdr eheader; \
 	      fseek(fp,0,SEEK_SET); \
@@ -41,6 +52,27 @@
 		  fseek(fp,eheader.e_shoff+(eheader.e_shnum)*eheader.e_shentsize,\
 			SEEK_SET); \
 				    } while(0)
+*/
+/* Seeking to the end of ELF data is a little messy... */
+#define SEEK_TO_END_OFILE(fp)\
+  do { \
+	long offset = 0, endofelf; int j; \
+	Elf32_Ehdr eheader; Elf32_Shdr shdr; \
+        fseek(fp, 0, SEEK_SET); \
+        fread(&eheader, sizeof(eheader), 1, fp); \
+  /* in case the headers themselves come AFTER the actual sections */ \
+	endofelf=offset = eheader.e_shoff+ eheader.e_shentsize *eheader.e_shnum;\
+        fseek(fp, eheader.e_shoff, SEEK_SET); \
+	if ( eheader.e_shentsize != sizeof(Elf32_Shdr) ) \
+	  { FEerror("Bad ELF section header size",0); } \
+        for ( j = 0; j < eheader.e_shnum; j++ ) \
+	  { fread(&shdr,eheader.e_shentsize,1,fp); \
+            if ( (shdr.sh_offset > offset) && (shdr.sh_type != SHT_NOBITS) ) \
+	      { offset = shdr.sh_offset; endofelf = offset+shdr.sh_size; } \
+	  } \
+	if ( fseek(fp, endofelf, SEEK_SET) ) \
+	    FEerror("Bad ELF file",0); \
+      } while(0)
 
 
 #define USE_ATT_TIME
@@ -58,6 +90,10 @@
 #endif
 #endif
 
+#ifdef IN_SOCKETS
+#include <sys/file.h>
+#endif     
+
 #ifndef __svr4__
 /* sun release 4.1,4.2 */
 #define SA_RESTART 0
@@ -106,13 +142,10 @@ do {static struct sigaction action; \
 	    sigaction(SIGSEGV,&action,0);	sigaction(SIGBUS,&action,0);} while (0)
 
 
-#include "sparc.h"
+
 
 /* Begin for cmpinclude */
-#ifndef __GNUC__
-#define HAVE_ALLOCA
-#include <alloca.h>
-#endif
+
  /* If can mprotect pages and so selective gc will work */
 #define SGC  
 
@@ -122,6 +155,9 @@ do {static struct sigaction action; \
 #ifdef IN_SFASL
 #include <sys/types.h>
 #include <sys/mman.h>
+#ifdef IS_X86     
+#include <sys/elf_386.h>
+#endif     
 /* we have to make the pages executable */
 #define CLEAR_CACHE do { unsigned long ps = getpagesize(); \
 			 char *beg = (unsigned long )(memory->cfd.cfd_start) & ~(ps-1); \
@@ -132,5 +168,6 @@ do {static struct sigaction action; \
 #endif
 
 #define HAVE_YP_UNBIND
-#undef  MAXPAGE 
-#define MAXPAGE (2*16384)
+
+
+
