@@ -25,21 +25,11 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 	value stack
 */
 
-/*
-#define	VSSIZE		2048
-*/
-					/*  value stack size  */
-#define	VSGETA		128		/*  value stack geta  */
+EXTER object *vs_org;
+EXTER object *vs_limit;	/*  value stack limit  */
 
-
-object value_stack[VSSIZE + (STACK_OVER +1) *VSGETA];
-
-
-object *vs_org;
-object *vs_limit;	/*  value stack limit  */
-
-object *vs_base;	/*  value stack base  */
-object *vs_top;		/*  value stack top  */
+EXTER object *vs_base;	/*  value stack base  */
+EXTER object *vs_top;		/*  value stack top  */
 
 #define	vs_push(obje)	(*vs_top++ = (obje))
 
@@ -60,6 +50,9 @@ object *vs_top;		/*  value stack top  */
 			if (vs_top - vs_base != (n))  \
 				check_arg_failed(n)
 
+#define CHECK_ARG_RANGE(n,m) if (VFUN_NARGS < n || VFUN_NARGS >m) \
+   check_arg_range(n,m)
+
 #define	MMcheck_arg(n)  \
 			if (vs_top - vs_base < (n))  \
 				too_few_arguments();  \
