@@ -549,15 +549,12 @@ DEFUN("MAKE-ARRAY1",object,fSmake_array1,SI,6,6,
 	return x;
       }
  }}
-      
-
-
-
-
-  
-
 
 /*
+  For the X->a.a_displaced field, the CAR is an array which X
+  's body is displaced to (ie body of X is part of Another array)
+  and the (CDR) is the LIST of arrays whose bodies are displaced
+  to X
  (setq a (make-array 2 :displaced-to (setq b (make-array 4 ))))
                 ;{  A->displ = (B), B->displ=(nil A)}
 (setq w (make-array 3))   ;; w->displaced= (nil y u) 
@@ -1040,7 +1037,7 @@ DEFUNO("REPLACE-ARRAY",object,fSreplace_array,SI,2,2,NONE,
     Icheck_displaced(DISPLACED_FROM(old),old,new->a.a_dim);
     adjust_displaced(old,offset);
 /*    Iundisplace(old); */
-    if (old->v.v_hasfillp)
+    if (TYPE_OF(old) == t_vector && old->v.v_hasfillp)
       { new->v.v_hasfillp = 1;
 	new->v.v_fillp = old->v.v_fillp;}
     if (TYPE_OF(old) == t_string)
