@@ -79,11 +79,12 @@ quick_call_sfun(fun)
 { DEBUG_AVMA
   int i,n;
   enum ftype restype;
-  object *x,res;
+  object *x,res,*base;
   object temp_ar[10];
   i=fun->sfn.sfn_argd;
   n=SFUN_NARGS(i);
-  if (n != vs_top -vs_base)
+  base = vs_base;
+  if (n != vs_top - base)
     {check_arg_failed(n);}
   restype = SFUN_RETURN_TYPE(i);
   SFUN_START_ARG_TYPES(i);
@@ -98,11 +99,12 @@ quick_call_sfun(fun)
        {enum ftype typ=SFUN_NEXT_TYPE(i);
 	x[j]=COERCE_ARG(vs_base[j],typ);}}
   SET_TO_APPLY(res,(object (*)())fun->sfn.sfn_self,n,x);
-  vs_base[0]=
+  base[0]=
     (restype==f_object ?  res :
      restype==f_fixnum ? make_fixnum((int)res)
      :(object) FEerror("Bad result type",0));
-  vs_top=vs_base+1;
+  vs_base = base;
+  vs_top=base+1;
   CHECK_AVMA;
   return;}
 
