@@ -6,7 +6,7 @@ Fast linking method for kcl by W. Schelter University of Texas
 
 #include "include.h"
 #include "sfun_argd.h"
-
+#include "page.h"
 
 object sScdefn;
 typedef object (*object_func)();
@@ -16,7 +16,7 @@ int Rset = 0;
 
 void
 call_or_link(sym,link)
-int *link;
+void **link;
 object sym;
 {object fun;
  fun = sym->s.s_gfdef;
@@ -29,16 +29,16 @@ object sym;
  if (Rset==0) funcall(fun);
    else
    if (type_of(fun) == t_cfun)
-       { (void) vpush_extend((int) link,sLAlink_arrayA->s.s_dbind);
-	  (void) vpush_extend((int) *link,sLAlink_arrayA->s.s_dbind);	 
-         *link = (int) (fun->cf.cf_self);
+       { (void) vpush_extend( link,sLAlink_arrayA->s.s_dbind);
+	  (void) vpush_extend( *link,sLAlink_arrayA->s.s_dbind);	 
+         *link = (void *) (fun->cf.cf_self);
 	 (*(void (*)())(fun->cf.cf_self))();
        }
    else funcall(fun);}
 
 void
 call_or_link_closure(sym,link,ptr)
-int *link;
+void **link;
 object sym;
 object *ptr;
 {object fun;
@@ -47,10 +47,10 @@ object *ptr;
  if (type_of(fun) == t_cclosure
      && (fun->cc.cc_turbo))
    {if (Rset) {
-     (void) vpush_extend((int) link,sLAlink_arrayA->s.s_dbind);
-     (void) vpush_extend((int) *link,sLAlink_arrayA->s.s_dbind);
+     (void) vpush_extend( link,sLAlink_arrayA->s.s_dbind);
+     (void) vpush_extend( *link,sLAlink_arrayA->s.s_dbind);
      *ptr = (void *)(fun->cc.cc_turbo);
-     *link = (int) (fun->cf.cf_self);
+     *link = (void *) (fun->cf.cf_self);
      MMccall(fun, fun->cc.cc_turbo);}
     else
       {MMccall(fun, fun->cc.cc_turbo);}
@@ -61,9 +61,9 @@ object *ptr;
 	to take any arguments.   In the majority of C's this is legal */
      
    if (type_of(fun) == t_cfun)
-       { (void) vpush_extend((int) link,sLAlink_arrayA->s.s_dbind);
-	  (void) vpush_extend((int) *link,sLAlink_arrayA->s.s_dbind);	 
-         *link = (int) (fun->cf.cf_self);
+       { (void) vpush_extend( link,sLAlink_arrayA->s.s_dbind);
+	  (void) vpush_extend( *link,sLAlink_arrayA->s.s_dbind);	 
+         *link = (void *) (fun->cf.cf_self);
 	 (*(void (*)())(fun->cf.cf_self))();
        }
    else funcall(fun);}
@@ -71,57 +71,51 @@ object *ptr;
 /* for pushing item into an array, where item is an address if array-type = t
 or a fixnum if array-type = fixnum */
 
+#define SET_ITEM(ar,ind,val) (*((object *)(&((ar)->ust.ust_self[ind]))))= val
+int     
 vpush_extend(item,ar)
-int item; object ar;
-{ register int ind = ar->v.v_fillp;
-  if (ind < ar->fixa.fixa_dim)
-   {ar->fixa.fixa_self[ind] = item;
-    return(ar->v.v_fillp = ++ind);}
+void *item; object ar;
+{ register int ind = ar->ust.ust_fillp;
+ AGAIN:
+  if (ind < ar->ust.ust_dim)
+   {SET_ITEM(ar,ind,item);
+    ind += sizeof(void *); 
+    return(ar->v.v_fillp = ind);}
        else
     { register int *oldp ;
-      int newdim=(2 + (int) (1.3 * ind));
-      char *newself;
-      newself=alloc_relblock(sizeof(int)*newdim);
-      oldp= ar->fixa.fixa_self;
-      ar->fixa.fixa_dim=newdim;
-      ar->fixa.fixa_self=(fixnum *)newself;
-      
-     /* this should be ok since the gc may be called at allocself, but when the
-actual allocation takes place, the array is still pointing to its old body,
-and the gc will not be called while we run through copying */
-     {register int *p = ar->fixa.fixa_self;
-      register int *last ;
-      last =  (p + ind);
-      while ( p < last)
-	*p++ = *oldp++;
-      *p=item;}
-      return(++(ar->v.v_fillp));
-    }
-  
-   }
+      int newdim= ROUND_UP_PTR((2 + (int) (1.3 * ind)));
+      unsigned char *newself;
+      newself = (void *)alloc_relblock(newdim);
+      bcopy(ar->ust.ust_self,newself,ind);
+      ar->ust.ust_dim=newdim;
+      ar->ust.ust_self=newself;
+      goto AGAIN;
+    }}
+
 
 /* if we unlink a bunch of functions, this will mean there are some
    holes in the link array, and we should probably go through it and
    push them back  */
 static int number_unlinked=0;
 
+void
 delete_link(address,link_ar) 
-     int address;
+     void *address;
      object link_ar;
-{int *ar,*ar_end,*p;
+{object *ar,*ar_end,*p;
  p=0;
- ar = link_ar->fixa.fixa_self;
- ar_end = ar +   link_ar->v.v_fillp;
+ ar = link_ar->v.v_self;
+ ar_end = (object *)&(link_ar->ust.ust_self[link_ar->v.v_fillp]);
  while (ar < ar_end)
-   { if (*ar && *((int *)*ar)==address)
-       { p = (int *) *ar;
+   { if (*ar && *((void **)*ar)==address)
+       { p = (object *) *ar;
 	 *ar=0;
 	 *p = *(ar+1);
 	 number_unlinked++;}
      ar=ar+2;}
  if (number_unlinked > 40)
    link_ar->v.v_fillp=
-     clean_link_array(link_ar->fixa.fixa_self,ar_end); }
+     clean_link_array(link_ar->ust.ust_self,ar_end); }
 
 
 DEFUN("USE-FAST-LINKS",object,fSuse_fast_links,SI,1,2,NONE,OO,OO,OO,OO,
@@ -136,10 +130,9 @@ va_dcl
 {int n = VFUN_NARGS;
  object sym;
  va_list ap;
- register int  *ar,*ar_end;
-  int *p;
-  object link_ar;
-  object fun;
+ object *p,*ar,*ar_end;
+ object link_ar;
+ object fun;
 
 { va_start(ap);
  if (n>=2) sym=va_arg(ap,object);else goto LDEFAULT2;
@@ -147,13 +140,15 @@ va_dcl
  LDEFAULT2: sym = Cnil ;
  LEND_VARARG: va_end(ap);}
 
-  if (sLAlink_arrayA ==0) return Cnil;
+  if (sLAlink_arrayA ==0)    RETURN1(Cnil);
   link_ar = sLAlink_arrayA->s.s_dbind;
   if (link_ar==Cnil && flag==Cnil) RETURN1(Cnil);
   check_type_array(&link_ar);
-  ar = link_ar->fixa.fixa_self;
-  ar_end = ar +   link_ar->v.v_fillp;
-    switch (n)
+  if (link_ar->v.v_elttype != aet_ch)
+  { FEerror("*LINK-ARRAY* must be a string",0);}
+  ar = link_ar->v.v_self;
+  ar_end = (object *)&(link_ar->ust.ust_self[link_ar->v.v_fillp]);
+ switch (n)
       {
   case 1:
    if (flag==Cnil)
@@ -161,7 +156,7 @@ va_dcl
      while ( ar < ar_end)
       /* set the link variables back to initial state */
 	 { 
-	    p = (int *) *ar;
+	    p = (object *) *ar;
 	    if (p) *p = (ar++, *ar); else ar++;
 	   ar++;
 	 }
@@ -191,7 +186,7 @@ va_dcl
       case t_cclosure:
       case t_closure:
       case t_afun:
-	delete_link((int)fun->cf.cf_self,link_ar);
+	delete_link(fun->cf.cf_self,link_ar);
 	/* becoming obsolete 
 	 y=getf(sym->s.s_plist,sScdefn,Cnil);
 	 if (y!=Cnil)
@@ -199,21 +194,23 @@ va_dcl
 	   */
 
       break;
-    
+       default: 
+        /* no link for uncompiled functions*/
+        break;	
     }
   }
     break;
   default:
     FEerror("Usage: (use-fast-links {nil,t} &optional fun)",0);
-   RETURN1(Cnil);
 }
+  RETURN1(Cnil);
 }
 
-
+int
 clean_link_array(ar,ar_end)
-int *ar,*ar_end;
+object *ar,*ar_end;
 {int i=0;
- int *orig;
+ object *orig;
  orig=ar;
  number_unlinked=0;
   while( ar<ar_end)
@@ -223,7 +220,7 @@ int *ar,*ar_end;
        }
    else ar=ar+2;       
     }
- return(i);
+ return(i*sizeof(object *));
  }
 
 #include <varargs.h>
@@ -552,7 +549,7 @@ c_apply_n(fn,n,x)
          x[43],x[44],x[45],x[46],x[47],x[48],x[49],
          x[50],x[51],x[52],x[53],x[54],x[55],x[56],
          x[57],x[58],x[59],x[60],x[61],x[62],x[63]);break;
-  default: FEerror("Exceeded call-arguments-limit ");
+  default: FEerror("Exceeded call-arguments-limit ",0);
   } 
 
  return res;
@@ -565,7 +562,8 @@ file */
 object
 call_proc(sym,link,argd,ll)
 object sym;
-int argd, *link;
+int argd;
+void  **link;
 va_list ll;
 {object fun;
  int nargs;
@@ -597,9 +595,9 @@ va_list ll;
 	  FEerror("Arg or result mismatch in call to  ~s",1,sym);
       }
    
-    (void) vpush_extend((int) link,sLAlink_arrayA->s.s_dbind);
-    (void) vpush_extend((int) *link,sLAlink_arrayA->s.s_dbind);	 
-    *link = (int)fn;
+    (void) vpush_extend(link,sLAlink_arrayA->s.s_dbind);
+    (void) vpush_extend(*link,sLAlink_arrayA->s.s_dbind);	 
+    *link = (void *)fn;
   AFTER_LINK:	
  
     if (nargs < 10) 
@@ -648,7 +646,7 @@ va_list ll;
 	return(c_apply_n(fn,nargs,new));}
   }
  else				/* there is no cdefn property */
-regular_call:
+/* regular_call: */
    { 
      object fun;
      register object *base;
@@ -689,27 +687,39 @@ regular_call:
 
 object call_vproc(sym,link,ll)
 object sym;
-int *link;
+void *link;
 va_list ll;     
 {return call_proc(sym,link,VFUN_NARGS | VFUN_NARG_BIT,ll);}
 
 object
 call_proc0(sym,link)
 object sym;
-int *link;
+void *link;
 {return call_proc(sym,link,0,0);}
 
+#if 0
 object
-call_proc1(sym,link,x0)
-     object sym,x0;int *link;
+call_proc1(sym,link,va_alist)
+     object sym,x0;void *link;
+     va_dcl
      
-{return (call_proc(sym,link,1,x0));}
+{  va_list ll;
+   va_start(ll);
+return (call_proc(sym,link,1,ll));
+    va_end(ll);
+}
 
 object
-call_proc2(sym,link,x0,x1)
-     object sym,x0,x1;int *link;
-{return (call_proc(sym,link,2,x0,x1));}
-
+call_proc2(sym,link,va_alist)
+     object sym,x0,x1;void *link;
+     va_dcl  
+{ va_list ll;
+   va_start(ll);
+   return (call_proc(sym,link,2,ll));
+    va_end(ll);
+}
+  
+#endif
 
    
 
@@ -769,6 +779,7 @@ va_dcl
 
 #define FRESH 40
 
+int
 clear_stack(beg,limit)
 object *beg,*limit;
 {int i=0;
@@ -782,22 +793,30 @@ set_mv(i,val)
      int i;
      object val;
 { if (i >= (sizeof(MVloc)/sizeof(object)))
-     FEerror("Bad mv index");
+     FEerror("Bad mv index",0);
   return(MVloc[i]=val);
 }
 
+
 object
 mv_ref(i)
      unsigned int i;
-{ if (i >= (sizeof(MVloc)/sizeof(object)))
-     FEerror("Bad mv index");
-  return (MVloc[i]);
+{ object x;
+  if (i >= (sizeof(MVloc)/sizeof(object)))
+     FEerror("Bad mv index",0);
+  x = MVloc[i];
+  if (x == 0)
+      FEerror("Null value",0);
+  return x;
 }
 
+
 #include "xdrfuns.c"
 
 DEF_ORDINARY("CDEFN",sScdefn,SI,"");
 DEFVAR("*LINK-ARRAY*",sLAlink_arrayA,LISP,Cnil,"");
+
+void
 init_links()
 {	
 
