@@ -20,8 +20,13 @@ Lsave()
 	check_arg(1);
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 	coerce_to_filename(vs_base[0], filename);
-
+#ifdef CLEANUP_CODE
+	CLEANUP_CODE
+#else
+#ifdef USE_CLEANUP
 	_cleanup();
+#endif	
+#endif
 	memory_save(kcl_self, filename);
 
 	exit(0);
