@@ -26,6 +26,8 @@ via #include "../c/sfasl.c"
 
 #ifdef STAND
 #include "config.h"
+#include "gclincl.h"
+#define OUR_ALLOCA alloca
 #include <stdio.h>
 #include "mdefs.h"
 
@@ -61,13 +63,15 @@ int sfasldebug=0;
 #define STAT static
 #endif
 
-
-#define MAXPATHLEN 200
+#ifndef MAXPATHLEN
+#define MAXPATHLEN 256
+#endif
 #define PTABLE_EXTRA 20
 
 struct sfasl_info {
  struct syment *s_symbol_table;
  char *s_start_address;
+ char *s_start_data;
  char *s_my_string_table;
  int s_extra_bss;
  char *s_the_start;
@@ -124,7 +128,7 @@ object faslfile;
 	extra_bss=0;
 #ifdef STAND
 	strcpy(filename,faslfile);
-	fp=fopen(filename,RDONLY);
+	fp=fopen(filename,"r");
 #else
 	coerce_to_filename(faslfile, filename);
 	faslfile = open_stream(faslfile, smm_input, Cnil, sKerror);
@@ -163,17 +167,17 @@ object faslfile;
 	fseek(fp,(int)( N_SYMOFF(fileheader)),  0);
 	{
 	for (i = 0;  i < nsyms;  i++)
-		{fread((char *)&symbol_table[i], SYMESZ, 1, fp);
-	 	dprintf( symbol table %d , i);
-		 if (debug) describe_sym(i);
-	 	dprintf( at %d , &symbol_table[i]);
+	  { fread((char *)&symbol_table[i], SYMESZ, 1, fp);
+	    dprintf( symbol table %d , i);
+	    if (debug) describe_sym(i);
+	    dprintf( at %d , &symbol_table[i]);
 #ifdef HPUX
-		 symbol_table[i].n_un.n_strx = string_size;
-		 dprintf(string_size %d, string_size);
-		 string_size += symbol_table[i].n_length + 1;
-		 fseek(fp,(int)symbol_table[i].n_length,1);
+	    symbol_table[i].n_un.n_strx = string_size;
+	    dprintf(string_size %d, string_size);
+	    string_size += symbol_table[i].n_length + 1;
+	    fseek(fp,(int)symbol_table[i].n_length,1);
 #endif
-	       }
+	  }
        }
 /*	
 on MP386
@@ -231,6 +235,7 @@ SEEK_TO_END_OFILE(fp);
         the_start=start_address=        
 	 memory->cfd.cfd_start =	
 	 alloc_contblock(memory->cfd.cfd_size);
+	sfaslp->s_start_data = start_address + textsize;
 	 END_NO_INTERRUPT;
        }
 #else
@@ -238,6 +243,7 @@ SEEK_TO_END_OFILE(fp);
 	  = malloc(datasize+textsize+bsssize + extra_bss + 0x80000);
 	the_start=start_address= (char *)(
 	   0x1000* ((((int)the_start + 0x70000) + 0x1000)/0x1000));
+	sfaslp->s_start_data = start_address + textsize;	
 	
 #endif
 
@@ -276,6 +282,9 @@ SEEK_TO_END_OFILE(fp);
      for(j=1; j< BSS_NSCN ; j++)
        { dprintf( relocating section %d \n,j);
 	if (section[j].s_nreloc) fseek(fp,section[j].s_relptr,0);
+#ifdef ADJUST_RELOC_START
+ADJUST_RELOC_START(j)
+#endif  
         for(i=0; i < section[j].s_nreloc; i++)
 	  /* RELSZ = sizeof(relocation_info) */
 	  {fread(&relocation_info, RELSZ, 1, fp);
@@ -396,7 +405,7 @@ FIND_INIT
      strcmp(sym->n_name,"_ptrgl")==0)
    {struct syment* s =
       get_symbol("._ptrgl",TEXT_NSCN,sym_table,length);
-    if (s ==0) FEerror("bad glue",0);
+    if (s ==0) FEerror("bad glue",0,0);
     sym->n_value = next_bss ;
     ptrgl_offset = next_bss;
     ptrgl_text = s->n_value;
@@ -497,7 +506,19 @@ unsigned int length;
    case N_ABS : case N_TEXT: case N_DATA: case N_BSS:
 #endif
 #ifdef COFF
+#ifdef  WINDOWSNT
+   case TEXT_NSCN:
+     sym->n_value = (int)start_address;
+     break;
+   case DATA_NSCN:
+     sym->n_value = (int)sfaslp->s_start_data;
+     break;
+   case BSS_NSCN: 
+    if (strcmp(".bss",SYM_NAME(sym))!= 0)
+      printf("dont do bss %s",SYM_NAME(sym));
+#else
    case TEXT_NSCN : case DATA_NSCN: case BSS_NSCN :
+#endif     
 #endif
      str=SYM_NAME(sym);
      dprintf( for sym %s ,str)
