@@ -126,6 +126,11 @@ DEV_FOUND:
 #endif   /* not GETCWD */
 #endif
 
+#ifndef MAXPATHLEN
+#define MAXPATHLEN 512
+#endif
+
+
 #ifdef GETCWD
 char *
 getwd(buffer)
