@@ -37,12 +37,6 @@ EXTER
 unsigned long s4_neg_int[4],small_neg_int[3],small_pos_int[3];
 #endif
 
-tes()
-{void *buf[70];
- void **p=buf;
-#define XS(a) *p++ = (void *) (a)
-#include "usig2_aux.c"
-}
  
 /* 
    We have two mechanisms for protecting against interrupts.  1] We have a
@@ -78,7 +72,7 @@ struct save_for_interrupt{
 
 #undef SS1
 #undef RS1
-#define SS1(a,b) a = b ;
+#define SS1(a,b) a =  b ;
 #define RS1(a,b) b = a ;
 
            /* save objects in save_objects list  */   
@@ -107,7 +101,7 @@ char signals_handled [] = {SIGINT,SIGUSR2,SIGUSR1,SIGIO,SIGALRM,0};
       does the longjmp.
 
 
-/* If we invoke signal handling routines at a storage
+   If we invoke signal handling routines at a storage
    allocation pt, it is completely safe:  we should save
    some of the globals, but the freelists etc dont need
    to be saved.   pass: sig_safe to raise_pending.
@@ -213,7 +207,7 @@ before_interrupt(p,allowed)
 	    { char *beg =  (char *) (p->free1[i]);
 	      object x = (object)beg;
 	      int amt = ad->tm_size;
-	      SS1(p->free2[i],FL_LINK(p->free1[i]));
+	      SS1(p->free2[i],OBJ_LINK(p->free1[i]));
 	      ad->tm_nfree --;
 	      bcopy(beg ,&(p->buf[i]), amt);
 	      bzero(beg+8,amt-8);
@@ -223,11 +217,11 @@ before_interrupt(p,allowed)
 		  beg = (char *)x;
 		  x->d.m = 0;
 		  bzero(beg+8,amt-8);
-		  SS1(ad->tm_free,FL_LINK(p->free2[i]));
+		  SS1(ad->tm_free,OBJ_LINK(p->free2[i]));
 		  ad->tm_nfree --;
 		}
 	      else
-		{ SS1(ad->tm_free,FL_LINK(p->free1[i]));
+		{ SS1(ad->tm_free, OBJ_LINK(p->free1[i]));
 		}}
 	}}
    }
@@ -241,7 +235,8 @@ before_interrupt(p,allowed)
  SS1(p->ihs_topVAL,*ihs_top);
  { void **pp = p->save_objects;
 #undef XS
-#define XS(a) *pp++ = (void *) (a);
+ /* #define XS(a) *pp++ = (void *) (a); */
+#define XS(a) *pp++ =  * (void **) (&a); 
 #include "usig2_aux.c"
    if ((pp - (&(p->save_objects)[0])) >= (sizeof(p->save_objects)/sizeof(void *)))
      abort();
@@ -250,7 +245,7 @@ before_interrupt(p,allowed)
  p->token_st_dim = MINN(token->st.st_dim,tok_leng+1);
  if (p->token_st_dim < sizeof(p->token_buf))
    p->token_bufp = p->token_buf;
- else { p->token_bufp= OUR_ALLOCA(p->token_st_dim);}
+ else { p->token_bufp= (void *)OUR_ALLOCA(p->token_st_dim);}
  bcopy(token->st.st_self,p->token_bufp,p->token_st_dim);
   
 }
@@ -271,14 +266,14 @@ after_interrupt(p,allowed)
 	    { char *beg =  (char *) (p->free1[i]);
 	      object x = (object)beg;
 	      int amt = ad->tm_size;
-	      RS1(p->free2[i],FL_LINK(p->free1[i]));
+	      RS1(p->free2[i],(p->free1[i]));
 	      if (x->d.m) error("should not be free");
 	      bcopy(&(p->buf[i]),beg, amt);
 	      if (p->free2[i])
 		{ x = (object) p->free2[i];
 		  if (x->d.m) error("should not be free");
 		  x->d.m = FREE;
-		  FL_LINK(FL_LINK(ad->tm_free)) = current_fl;
+		  F_LINK(F_LINK(ad->tm_free)) = (long )current_fl;
 		  ad->tm_nfree += 2;
 		}
 	      else
@@ -298,8 +293,12 @@ after_interrupt(p,allowed)
   RS1(p->ihs_topVAL,*ihs_top);
  { void **pp = p->save_objects;
 #undef XS
-/* #define XS(a) ((void *)a) =  *pp++ */
-#define XS(a) a = (void *)(*pp++)
+
+ /*  #define XS(a) a = (void *)(*pp++)
+     We store back in the location 'a' the value we have saved. 
+  */
+ 
+#define XS(a) do { void **_p = (void **)(&a); *_p = (void *)(*pp++);}while(0)
 #include "usig2_aux.c"
  }
 
@@ -332,7 +331,7 @@ MakeCons(a,b)
       So the above three operations can occur in any order.
       */
 
-  { object tem  = FL_LINK(new);
+  { object tem  = OBJ_LINK(new);
     /*
       interrupt here and we see that before_interrupt must save the top of the
       free list AND the second thing on the Free list.  That way we will be ok
