@@ -182,7 +182,9 @@ char *filename;
 
 struct lsymbol_table tab;
 
-#define EXT_and_TEXT_BSS_DAT(p) ((ELF32_ST_BIND(p->st_info) == STB_GLOBAL) \
+#define EXT_and_TEXT_BSS_DAT(p) (((ELF32_ST_BIND(p->st_info) == STB_GLOBAL) \
+				  || (ELF32_ST_BIND(p->st_info) == STB_WEAK) \
+				  ) \
 				 && \
 				 (p->st_shndx == text_index \
 				  || p->st_shndx == data_index\
